"use strict";
// Copyright 2017-2020 @polkadot/jsonrpc authors & contributors
// This software may be modified and distributed under the terms
// of the Apache-2.0 license. See the LICENSE file for details.
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const method_1 = __importDefault(require("./create/method"));
// NOTE order here is the same as in Rust, alphabetical below
const name = {
    description: 'Retrieves the node name',
    params: [],
    type: 'Text'
};
const version = {
    description: 'Retrieves the version of the node',
    params: [],
    type: 'Text'
};
const chain = {
    description: 'Retrieves the chain',
    params: [],
    type: 'Text'
};
const properties = {
    description: 'Get a custom set of properties as a JSON object, defined in the chain spec',
    params: [],
    type: 'ChainProperties'
};
const health = {
    description: 'Return health status of the node',
    params: [],
    type: 'Health'
};
const peers = {
    description: 'Returns the currently connected peers',
    params: [],
    type: 'Vec<PeerInfo>'
};
const networkState = {
    description: 'Returns current state of the network',
    params: [],
    type: 'NetworkState'
};
const section = 'system';
/**
 * @summary Calls to retrieve system info.
 */
exports.default = {
    isDeprecated: false,
    isHidden: false,
    description: 'Calls to retrieve system info',
    section,
    methods: {
        chain: method_1.default(section, 'chain', chain),
        health: method_1.default(section, 'health', health),
        name: method_1.default(section, 'name', name),
        networkState: method_1.default(section, 'networkState', networkState),
        peers: method_1.default(section, 'peers', peers),
        properties: method_1.default(section, 'properties', properties),
        version: method_1.default(section, 'version', version)
    }
};
